@@ -1,4 +1,5 @@
 import importlib.resources
+import importlib.resources
 import json
 
 import pytest
@@ -8,9 +9,16 @@ import python_jsonschema_objects as pjs
 
 @pytest.fixture
 def markdown_examples():
-    with importlib.resources.path(
-        "python_jsonschema_objects.examples", "README.md"
-    ) as md:
+    if hasattr(importlib.resources, "as_file"):
+        filehandle = importlib.resources.as_file(
+            importlib.resources.files("python_jsonschema_objects.examples")
+            / "README.md"
+        )
+    else:
+        filehandle = importlib.resources.path(
+            "python_jsonschema_objects.examples", "README.md"
+        )
+    with filehandle as md:
         examples = pjs.markdown_support.extract_code_blocks(md)
 
     return {json.loads(v)["title"]: json.loads(v) for v in examples["schema"]}
