@@ -14,7 +14,6 @@ import jsonschema
 import referencing.jsonschema
 import referencing.retrieval
 import referencing._core
-import six
 from referencing import Registry, Resource
 
 import python_jsonschema_objects.classbuilder as classbuilder
@@ -43,7 +42,7 @@ class ObjectBuilder(object):
         resolver: Optional[referencing.typing.Retrieve] = None,
         specification_uri: Optional[str] = None,
     ):
-        if isinstance(schema_uri, six.string_types):
+        if isinstance(schema_uri, str):
             uri = os.path.normpath(schema_uri)
             self.basedir = os.path.dirname(uri)
             with codecs.open(uri, "r", "utf-8") as fin:
@@ -125,11 +124,14 @@ class ObjectBuilder(object):
                 DeprecationWarning,
             )
         for uri, contents in resolved.items():
+            from referencing.jsonschema import specification_with
+
+            specification = specification_with(
+                specification_uri or self.schema["$schema"]
+            )
             self.registry = self.registry.with_resource(
                 "memory:" + uri,
-                referencing.Resource.from_contents(
-                    contents, specification_uri or self.schema["$schema"]
-                ),
+                referencing.Resource.from_contents(contents, specification),
             )
 
         validatorClass = jsonschema.validators.validator_for(
@@ -183,7 +185,13 @@ class ObjectBuilder(object):
         except jsonschema.ValidationError as e:
             raise ValidationError(e)
 
-    def build_classes(self, strict=False, named_only=False, standardize_names=True):
+    def build_classes(
+        self,
+        strict=False,
+        named_only=False,
+        standardize_names=True,
+        any_of: typing.Optional[typing.Literal["use-first"]] = None,
+    ):
         """
         Build all of the classes named in the JSONSchema.
 
@@ -201,14 +209,17 @@ class ObjectBuilder(object):
                 generated).
             standardize_names: (bool) If true (the default), class names will be
                 transformed by camel casing
+            any_of: (literal) If not set to None, defines the way anyOf clauses are resolved:
+                - 'use-first': Generate to the first matching schema in the list under the anyOf
+                - None: default behavior, anyOf is not supported in the schema
 
         Returns:
             A namespace containing all the generated classes
 
         """
-        kw = {"strict": strict}
+        kw = {"strict": strict, "any_of": any_of}
         builder = classbuilder.ClassBuilder(self.resolver)
-        for nm, defn in six.iteritems(self.schema.get("definitions", {})):
+        for nm, defn in self.schema.get("definitions", {}).items():
             resolved = self.resolver.lookup("#/definitions/" + nm)
             uri = python_jsonschema_objects.util.resolve_ref_uri(
                 self.resolver._base_uri, "#/definitions/" + nm
@@ -217,19 +228,19 @@ class ObjectBuilder(object):
 
         if standardize_names:
             name_transform = lambda t: inflection.camelize(
-                inflection.parameterize(six.text_type(t), "_")
+                inflection.parameterize(str(t), "_")
             )
         else:
             name_transform = lambda t: t
 
         nm = self.schema["title"] if "title" in self.schema else self.schema["$id"]
-        nm = inflection.parameterize(six.text_type(nm), "_")
+        nm = inflection.parameterize(str(nm), "_")
 
         builder.construct(nm, self.schema, **kw)
         self._resolved = builder.resolved
 
         classes = {}
-        for uri, klass in six.iteritems(builder.resolved):
+        for uri, klass in builder.resolved.items():
             title = getattr(klass, "__title__", None)
             if title is not None:
                 classes[name_transform(title)] = klass
